@@ -22,6 +22,61 @@
 
 #include "braille-encoder.h"
 
+static BrailleContext** _braille_contexts = NULL;
+
+BrailleContext* BRAILLE_CONTEXT_ALL;
+BrailleContext* BRAILLE_CONTEXT_ALPHA;
+
+BrailleContext*
+braille_context_add_new (gchar *name)
+{
+    BrailleContext *context;
+    gint n_contexts = 0;
+    if (_braille_contexts == NULL)
+    {
+	context = g_new (BrailleContext, 1);
+	context->name = name;
+	n_contexts = 1;
+	_braille_contexts = g_new (BrailleContext *, n_contexts + 1);
+    }
+    else
+    {
+	while (_braille_contexts[n_contexts]) 
+	{
+	    if (!strcmp (_braille_contexts[n_contexts]->name, name))
+	    {
+		return _braille_contexts[n_contexts];
+	    }
+	    n_contexts++;
+	}
+	n_contexts++;
+	_braille_contexts = g_renew (BrailleContext *, _braille_contexts, n_contexts + 1);
+    }
+    context = g_new (BrailleContext, 1);
+    context->name = name;
+    _braille_contexts[n_contexts - 1] = context;
+    _braille_contexts[n_contexts] = NULL;
+
+    return context;
+}
+
+BrailleContext**
+braille_get_contexts (void)
+{
+    if (_braille_contexts == NULL)
+    {
+	BRAILLE_CONTEXT_ALL = braille_context_add_new (g_strdup ("all"));
+	BRAILLE_CONTEXT_ALPHA = braille_context_add_new (g_strdup ("alpha"));
+    }
+    return _braille_contexts;
+}
+
+gboolean
+braille_context_match (BrailleContext *a, BrailleContext *b)
+{
+    return ((!a && !b) || (a == b) || (a && b && ((a->name == b->name) || !strcmp (a->name, b->name))));
+}
+
 GType
 braille_encoder_get_type (void)
 {
